import java.io.BufferedInputStream;
import java.io.BufferedOutputStream;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;


public class DownloadINPE {
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {

		if (args.length != 2) {
			System.out.println("Usage: java download <url> <destination_path>");
			System.out.println("Example: java download http://oiswww.eumetsat.org/SDDI/html/grib.html D:\\");
			System.out.println("Note: use quotes for paths with spaces.");
			
		} else {
//			String startUrl = "http://oiswww.eumetsat.org/SDDI/html/grib.html";
//			String destination = "D:\\";
			String startUrl = args[0];
			String destination = args[1];			
			download(startUrl, destination);
		}
		
	}
		
	static private void download(String startUrl, String destination) {
		try {
			String base = startUrl.substring(0, startUrl.lastIndexOf('/'));
			
			System.out.println("Fetching '" + startUrl + "'");
			URL url = new URL(startUrl);
			BufferedReader reader = new BufferedReader(new InputStreamReader(url.openStream()));

			String line = reader.readLine();
			while (line != null) {
				String str = findString(line, ".zip");
				if (str != null) {
					String file = base + "/" + str;
					DownloadFile(file, destination, false);
				}
				line = reader.readLine();
			}
			reader.close();
			
		} catch (MalformedURLException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		}

	}
	
	static private String findString(String line, String pattern) {
		String ret = null;		
		int start = line.indexOf(pattern);		
		if (start >= 1) {
			int leftQuote = line.lastIndexOf('"', start);
			int rightQuote = line.indexOf('"', start);
			if (leftQuote >= 0 && rightQuote >= 0 && leftQuote < rightQuote && rightQuote < line.length())
				ret = line.substring(leftQuote + 1, rightQuote);
		}
		return ret;		
	}
	
	private static final int bufSize = 65536;
	private static final byte [] buf = new byte[bufSize]; 
	
	private static void DownloadFile(String file, String destination, boolean force) throws IOException {
		String slash = (destination != null && (destination.endsWith("/") || destination.endsWith("\\")))?"":"\\";
		String outFile = destination + slash + file.substring(file.lastIndexOf('/') + 1);
		File f = new File(outFile);
		if (force || (!f.exists())) {
			System.out.println("Downloading file '" + file.substring(file.lastIndexOf('/') + 1) + "'");
			URL fileUrl = new URL(file);
			BufferedInputStream bis = new BufferedInputStream(fileUrl.openStream());
			BufferedOutputStream ost = new BufferedOutputStream(new FileOutputStream(outFile));
	
			int total = bis.read(buf);
			while (total > -1) {
				ost.write(buf, 0, total);
				total = bis.read(buf);
			}
			ost.close();
			bis.close();
		} else {
			System.out.println("Skipping file '" + file.substring(file.lastIndexOf('/') + 1) + "' as it already exists");
		}
	}

}
